---
title: Community
description: Become part of the IPFS community! Learn how here.
sidebarDepth: 3
---

# Community

IPFS is home to a vibrant, diverse community of thousands of contributors and participants from all over the globe! Here's how to get help, support, or just hang out with other folks who are helping to build the distributed web.


:::callout
The IPFS community believes that our mission is best served in an environment that is friendly, safe, and accepting, and free from intimidation or harassment. To that end, we ask that everyone involved in IPFS read and respect our [code of conduct](https://github.com/ipfs/community/blob/master/code-of-conduct.md). Please contact [abuse@ipfs.tech](mailto:abuse@ipfs.tech) if you need to report a problem or address a grievance related to an abuse report.
:::

- [Get technical support and help in the IPFS forum](#get-technical-support-and-help) as you develop on IPFS.
- Get involved with the community through [apps like Discord and Slack](#chat), regularly occurring [community events such as demos and triage sessions](#community-events-calendar), and [the IPFS forum](#ipfs-forums).
- Stay informed and up to date on the latest developments in the IPFS ecosystem with [social media](#social-media) and [the IPFS newsletter](#ipfs-newsletter).
- Navigate the IPFS ecosystem using [the ecosystem directory](#ecosystem-directory) and [Awesome IPFS](#awesome-ipfs).

## Get technical support and help

Are you developing with IPFS implementations and tools, and looking for technical support from IPFS experts? For the fastest possible assistance and resolution of your support needs, do the following:

1. [Check to see if the problem / issue you've encountered has already been discussed](#_1-check-to-see-if-the-issue-you-ve-encountered-has-already-been-discussed).
2. If your problem / issue has not been discussed or solved in the forum, [follow the general guidelines for getting useful answers to your questions](#_2-follow-the-guidelines-for-getting-useful-answers-to-your-questions). 
3. [Create a forum post in the Help section](#_3-create-a-forum-post-in-the-help-section).

:::tip 
To post in the IPFS forum, you'll need a (free) IPFS forum account if you don't already have one. To create an account, click the **Sign Up** button in the top right corner of the forum website. 
:::

### 1. Check to see if the issue you've encountered has already been discussed

1. Navigate to [the Help category of the IPFS forum](https://discuss.ipfs.tech/c/help/13).
1. In the upper right hand corner, click the search icon (a blue magnifying glass). The forum search bar opens.
1. In the search bar, type a term related to the issue you are trying to solve. Options to either search the Help category or search all forum topics and posts display.
1. Below the search bar, click the option to search for the term in the Help channel. Alternatively, you can search across all topics and posts. A list of forum posts related to your search displays.
1. Search through the list of posts returned. If you don't find the answer or help you're looking for, [follow the general guidelines for getting useful answers to your questions](#2-follow-the-guidelines-for-getting-useful-answers-to-your-questions).

### 2. Follow the guidelines for getting useful answers to your questions

Please following these general guidelines when asking for help:

- Before creating a forum post, summarize the issue / problem you are encountering. Example phrasings:
  - _Here's what I'm trying to do..._
  - _I did X and expected Y to happen..._
  - _Could this be because...?_
  - _This seems impossible because..._
  - _I've tried A, B and C to fix X, but..._
- When asking for help with one of the IPFS libraries, include the name of the exact package and version of the package/library.
- When sharing bits of code, [use markdown](../community/contribute/grammar-formatting-and-style.md#style) to format code blocks so that they are easier to read.
- Ensure that you've read the forum [FAQ](https://discuss.ipfs.tech/faq) and [Terms of Service](https://discuss.ipfs.tech/tos).
- Screenshots of errors are often helpful.

### 3. Create a forum post in the Help section

Keeping in mind [the general guidelines above](#_2-follow-the-guidelines-for-getting-useful-answers-to-your-questions), do the following:

1. In [the Help category of the forum](https://discuss.ipfs.tech/c/help/13), hover over the large blue circle with a `+` symbol in the center. The text **New Topic** displays.
1. Click **New Topic**.  The **Create a new Topic** modal opens.
1. In the title field, describe what the discussion is one brief sentence.
1. Add any optional tags that help describe what subcategory the issue is in. Samples options include `kubo` and `helia`.
1. Following the guidelines above, describe your issue / problem in the main text field. You can use Markdown, BBCode or HTML for formatting, and include images.
1. Click **Create Topic**. Your topic is has been created in the forum!

The forum moderators will attempt to address your post as quickly as possible. 

## Get involved

### IPFS forums

The official [IPFS forums](https://discuss.ipfs.tech/) are the primary home of IPFS-related discussion. Join the conversation on [https://discuss.ipfs.tech](https://discuss.ipfs.tech) for everything from support, technical questions, project brainstorming, IPFS use cases, and more.

### Community Events Calendar

If you're an IPFS implementer, application developer, or user, you are welcome to join the community meetings we host regularly.

Stay up-to-date by subscribing to the [**IPFS Community Calendar**](https://ipfs.fyi/calendar) and joining community meetings such as triage sessions, the IPFS implementers sync, and the IPLD sync.

### Chat

Casual chat fan? You can engage with the IPFS community in one of the channels listed below:

:::callout
In general, public IPFS Discord channels are bridged to Matrix and Slack. As a result, you can usually use your preferred chat application to engage with the community. IPFS channels/rooms are usually prefixed with "#ipfs-".
:::

- **Discord**: Join the [IPFS Discord server](https://discord.gg/ipfs) for synchronous chat.

- **Matrix**: Join the [Matrix space](https://matrix.to/#/#ipfs-space:ipfs.io). 

- **Slack**: Join [Filecoin slack](https://filecoin.io/slack) and join the bridged #ipfs channels. 

### Meetups

IPFS meetups are also all over the world. [Find one close to you](https://www.meetup.com/members/249142444/) ... or [contact IPFS Community on Meetup.com](https://secure.meetup.com/messages/?new_convo=true&member_id=249142444&name=IPFS+Community) to start your own in your area!

### Contribute

No matter your area of specialty or level of expertise, there are many [ways to contribute](contribute/ways-to-contribute.md) to IPFS and make a real difference in the IPFS community at large.


## Stay informed

### Social media

We're in a lot of places. Here's [how to find them all](social-media.md) for your favorite platforms.

### IPFS newsletter

Sign up for the IPFS Weekly newsletter to get project updates, community news, event details, and more. In your inbox every Tuesday. [Subscribe now!](https://ipfs.us4.list-manage.com/subscribe?u=25473244c7d18b897f5a1ff6b&id=cad54b2230)

### IPFS Blog 

The latest updates and info on IPFS in one place, from blog posts and release notes to videos, tutorials, news coverage, and events.
[Read the blog here](https://blog.ipfs.io/).

### YouTube

Learn more about IPFS in [the official IPFS YouTube channel](https://www.youtube.com/channel/UCdjsUXJ3QawK4O5L1kqqsew). It has lots of great educational material around IPFS. 

## Navigate the IPFS ecosystem

### Ecosystem directory

Explore the world of projects and products built on IPFS in the [Ecosystem directory](https://ecosystem.ipfs.io/) – an interactive showcase filterable by industry, tooling, and more.

If you want to add a new project to the IPFS ecosystem directory, use [this form](https://airtable.com/shrjwvk9pAeAk0Ci7).

### Awesome IPFS

Get inspired by [Awesome IPFS](https://awesome.ipfs.tech/), a catalog of community-built open-source projects using IPFS for everything from image sharing to decentralized archiving. Have a project of your own to add to Awesome IPFS? Make a PR [in the repo!](https://github.com/ipfs/awesome-ipfs).
