---
title: Ways to contribute
description: Learn about how to contribute to IPFS, the InterPlanetary File System.
---

# Ways to contribute

So you want to contribute to IPFS and the ecosystem? Here is a quick listing of things we need help with and how you can get started. Even if what you want to do is not listed here, we probably accept contributions for it! If you're unsure, please open an issue.

:::callout
The IPFS community believes that our mission is best served in an environment that is friendly, safe, and accepting, and free from intimidation or harassment. To that end, we ask that everyone involved in IPFS read and respect our [code of conduct](https://github.com/ipfs/community/blob/master/code-of-conduct.md). Please contact [abuse@ipfs.tech](mailto:abuse@ipfs.tech) if you need to report a problem or address a grievance related to an abuse report.
:::

## Code

IPFS and its sister-projects are big, with lots of code written in multiple languages. We always need help writing and maintaining code, but it can be daunting to just jump in. We use the label _Help Wanted_ on features or bug fixes that people can help out with. They are an excellent place for you to start contributing code.

The biggest and most active repositories we have today are:

- [ipfs/kubo](https://github.com/ipfs/kubo)
- [ipfs/helia](https://github.com/ipfs/helia)
- [libp2p/go-libp2p](https://github.com/libp2p/go-libp2p)
- [libp2p/js-libp2p](https://github.com/libp2p/js-libp2p)

If you want to start contributing to the core of IPFS, those repositories are a great place to start. But the _Help Wanted_ label exists in all of our repositories across the GitHub organizations:

- [IPFS](https://github.com/ipfs)
- [libp2p](https://github.com/libp2p)
- [IPLD](https://github.com/libp2p)
- [Multiformats](https://github.com/multiformats)

## Documentation

IPFS is a huge project and undertaking, and with lots of code comes the need for lots of good documentation! However, we need a lot more help to write the awesome docs the project needs.

Before contributing to the IPFS docs, please read these quick guides; they'll save you time and help keep the docs accurate and consistent!

1. [Style and formatting guide](grammar-formatting-and-style.md)
2. [Writing guide](writing-guide.md)
3. [Code persona](code-persona.md)

If you have never contributed to an open-source project before or just need a refresher, take a look at the [contribution tutorial](contribution-tutorial.md).

## Support

IPFS already has lots of users and curious people experimenting and using IPFS in their applications. These users sometimes get stuck or have questions that need answering. If you've contributed something with code or documentation, the chances are that you can probably help a lot of people with their questions.

The [IPFS forum](https://discuss.ipfs.tech/) is the best place to go if you're looking to give or get support.

## Testing

We're continuously improving IPFS every day, but mistakes can happen, and we could release something that doesn't work as well as it should — or simply doesn't work at all! If you enjoy instrumentation and testing, check out these projects.

- [ProbeLab](https://probelab.io/)
- [Interplanetary Testground](https://github.com/testground/testground)

## Design

We have many design needs, but only a small team of visual and UX designers who divide their time between IPFS-related projects and other work here. That means there are a number of issues that could use your design contributions. As home to IPFS Desktop and Companion, the [ipfs-gui](https://github.com/ipfs/ipfs-gui) repo is a good place to look for opportunities to help move our design work forward. Simply filter by the label that best fits your skill set, such as [design-visual](https://github.com/ipfs/ipfs-gui/issues?q=is%3Aissue+is%3Aopen+label%3Atopic/design-visual) or [design-ux](https://github.com/ipfs/ipfs-gui/labels/topic/design-ux).

## Applications

A few ways to discover applications, solutions, and tools built with IPFS.

- [IPFS Ecosystem Directory](https://ecosystem.ipfs.tech/)
- [ipfs/awesome-ipfs](https://github.com/ipfs/awesome-ipfs)
- [IPFS Forum](https://discuss.ipfs.tech/)

## Protocol Design

IPFS is ultimately about building better protocols, and we always welcome ideas and feedback on how to improve those protocols. Post feedback, issues, and proposals via GitHub.

- [ipfs/specs](https://github.com/ipfs/specs)
- [libp2p/specs](https://github.com/libp2p/specs)
- [ipld/specs](https://github.com/ipld/specs)
- [multiformats/specs](https://github.com/multiformats/specs)
- [ipfs/notes](https://github.com/ipfs/notes)
