---
title: Concepts
description: Get started on understanding the key ingredients in the decentralized web and how IPFS works.
---

# Concepts

Welcome to the Concepts section of the InterPlanetary File System (IPFS) docs. Here, you can:

- Learn what IPFS is and isn't, the problems it solves, the different subsystems that it is composed of and how each one works in [the 3-page Basic Concepts](#learn-the-basics).
- Dive into ideas like hashing, immutability, persistence (and more) that underlie IPFS in [Ideas and theory](#ideas-and-theory)
- Learn more about the subsystems that IPFS is composed of in [Subsystems and components](#subsystems-and-components)
- Get an [overview of IPFS implementations](../concepts/ipfs-implementations.md).
- [Compare IPFS to other similar systems](../concepts/comparisons.md).
- Get answers to common questions about IPFS in [the FAQ](../concepts/faq.md).
- Reference [the glossary of terms used in the IPFS ecosystem](../concepts/glossary.md).
- Read [academic papers written about IPFS, including the original IPFS whitepaper](../concepts/further-reading/academic-papers.md).
- Get inspired with [IPFS usage ideas and examples](#examples-and-case-studies).
- Learn about IPFS in theater mode with [these helpful videos](#video-overviews).

:::callout
### Don't see what you're looking for?

We're adding more documentation all the time and making ongoing revisions to existing docs, but if you don't see what you need, please [file an issue](https://github.com/ipfs/ipfs-docs/issues/new?assignees=&labels=OKR+3%3A+Content+Improvement%2C+docs-ipfs&template=content-request.md&title=%5BCONTENT+REQUEST%5D+%28add+your+title+here%21%29) to let us know! We also recommend visiting the [IPFS forums](https://discuss.ipfs.tech/) for support and discussion with IPFS enthusiasts and experts worldwide.
:::

## Learn the basics

1. [What IPFS is and isn't](../concepts/what-is-ipfs.md)
1. [IPFS and the problems it solves](../concepts/ipfs-solves.md)
1. [How IPFS works](../concepts/how-ipfs-works.md)

## Ideas and theory

- [Cryptographic hashing](hashing.md)
- [Immutability](immutability.md)
- [Persistence, permanence and pinning](persistence.md)
- [Privacy and encryption](privacy-and-encryption.md)
- [Nodes](nodes.md)

## Subsystems and components

- [Content Identifiers (CIDs)](content-addressing.md)
- [Bitswap](bitswap.md)
- [Distributed Hash Tables (DHTs)](dht.md)
- [DNSLink](dnslink.md)
- [File systems](file-systems.md)
- [IPFS Gateway](ipfs-gateway.md)
- [IPLD](ipld.md)
- [IPNS](ipns.md)
- [libp2p](libp2p.md)
- [Merkle Directed Acyclic Graphs (DAGs)](merkle-dag.md)

## Examples and case studies

- [Case study: Arbol](../case-studies/arbol.md)
- [Case study: Audius](../case-studies/audius.md)
- [Case study: Fleek](../case-studies/fleek.md)
- [Case study: LikeCoin](../case-studies/likecoin.md)
- [Case study: Morpheus.Network](../case-studies/morpheus.md)
- [Case study: Snapshot](../case-studies/snapshot.md)

## Video overviews

<!-- markdown-link-check-disable -->
@[youtube](Z5zNPwMDYGg)

- [Understanding how IPFS deals with files (IPFS Camp 2019)](https://youtu.be/Z5zNPwMDYGg)

@[youtube](fLUq0RkiTBA)

- [The lifecycle of data in the DWeb (IPFS Camp 2019)](https://youtu.be/fLUq0RkiTBA)

@[youtube](J-drqD2UebM)

- [IPFS: A Whiteboard Overview](https://www.youtube.com/watch?v=J-drqD2UebM)
<!-- markdown-link-check-enable-->
Check out ResNetLab on Tour for complete tutorials on IPFS and the Web 3.0 stack:

- [ResNetLab on Tour 2021](https://research.protocol.ai/tutorials/resnetlab-on-tour/)


## Further reading

Want a more in-depth look into the decentralized web? Here are a few papers that are useful for understanding IPFS, whether it be understanding the IPFS spec itself or the background for the web, protocols, hashing, and so on. [Read the papers →](further-reading/academic-papers.md)
